Term
====

Frame
-----

.. currentmodule:: fastobo.term
.. automodule:: fastobo.term


.. autoclass:: TermFrame(AbstractEntityFrame)
   :members:
   :special-members:


Clauses
-------


.. autoclass:: BaseTermClause(AbstractEntityClause)
   :members:
   :special-members:

.. autoclass:: AltIdClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: BuiltinClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: CommentClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: ConsiderClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: CreatedByClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: CreationDateClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: DefClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: DisjointFromClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: EquivalentToClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: IntersectionOfClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: IsAClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: IsAnonymousClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: IsObsoleteClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: NameClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: NamespaceClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: PropertyValueClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: RelationshipClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: ReplacedByClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: SubsetClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: SynonymClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: UnionOfClause(BaseTermClause)
  :members:
  :special-members:

.. autoclass:: XrefClause(BaseTermClause)
  :members:
  :special-members:
